<?xml version="1.0" encoding="utf-8"?>

<!-- 
	Version 2.6
	27 March 2006

	Author:
		Laurent Desqueper
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:ectd="http://www.ich.org/ectd" 
	xmlns:xlink="http://www.w3c.org/1999/xlink">

<!-- Key used for the indirection from the document zone to the tree zone -->
<xsl:key name = "level_id" match = "*" use = "@level_id" /> 

<!-- Check if all the parts of the list contain same or different elements
		Param: 	list contains the elements to check
						ref-a is the first part to compare
						ref-b is the second part to compare
-->
<xsl:template name="getDiff">
	<xsl:param name="list"/>
	<xsl:param name="ref-a"/>
	<xsl:param name="ref-b"/>
	
	<xsl:variable name="new-ref-a">
		<xsl:choose>
			<xsl:when test="$ref-a = ''"><xsl:value-of select="substring-before($list, '/')"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="$ref-a"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:if test="$ref-b !='' and $new-ref-a != $ref-b">N</xsl:if>
			
	<xsl:variable name="new-ref-b" select="substring-before($list, '/')"/>
	<xsl:variable name="todo" select="substring-after($list, '/')"/>
			
	<xsl:if test="string-length($new-ref-b) > 0">
		<xsl:call-template name="getDiff">
			<xsl:with-param name="list" select="$todo"/>
			<xsl:with-param name="ref-a" select="$new-ref-a"/>
			<xsl:with-param name="ref-b" select="$new-ref-b"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<!-- Calculate the sum of numbers
		Param: 	list contains the series of numbers to sum, delimited by a + sign
						subtotal is the intermediate result of the sum
-->
<xsl:template name="getSum">
	<xsl:param name="list"/>
	<xsl:param name="subTotal">0</xsl:param>

	<xsl:variable name="item" select="substring-before($list, '+')"/>
	<xsl:variable name="rest" select="substring-after($list, '+')"/>
	
	<xsl:choose>
		<xsl:when test="string-length($item) > 0">
			<xsl:variable name="currentTotal" select="$subTotal + $item"/>
			<xsl:call-template name="getSum">
				<xsl:with-param name="list" select="$rest"/>
				<xsl:with-param name="subTotal" select="$currentTotal"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise><xsl:value-of select="$subTotal"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Count the number of elements that should display in the document to generate
		Param:		level is the level in the tree zone, either prd (0), frm (1), str (2) or prs (3)
						element is the name of the element to display
 -->
<xsl:template name="countElement">
	<xsl:param name="level"/>
	<xsl:param name="element"/>

	<xsl:variable name="diff" select="$level - $depth"/>
	
	<xsl:variable name="totalList">
		<xsl:choose>
			<xsl:when test="$diff > 0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:value-of select="count(key('level_id', $level_id)//*[name()=$element])"/>+</xsl:for-each>
			</xsl:when>
			<xsl:when test="$diff=0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:value-of select="count(key('level_id', $level_id)/*[name()=$element])"/>+</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
				<xsl:choose>
					<xsl:when test="$diff = -1"><xsl:value-of select="count(key('level_id', $level_id)/../*[name()=$element])"/>+</xsl:when>
					<xsl:when test="$diff = -2"><xsl:value-of select="count(key('level_id', $level_id)/../../*[name()=$element])"/>+</xsl:when>
					<xsl:when test="$diff = -3"><xsl:value-of select="count(key('level_id', $level_id)/../../../*[name()=$element])"/>+</xsl:when>
					<xsl:when test="$diff = -4"><xsl:value-of select="count(key('level_id', $level_id)/../../../../*[name()=$element])"/>+</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:call-template name="getSum">
		<xsl:with-param name="list" select="$totalList"/>
	</xsl:call-template>
</xsl:template>

<!-- Count the number of elements that should display in the document to generate, with a given location
		Param:		level is the level in the tree zone, either prd (0), frm (1), str (2) or prs (3)
						element is the name of the element to display
						location is the location value for the additional section in leaflet
 -->
<xsl:template name="countElementWithLocation">
	<xsl:param name="level"/>
	<xsl:param name="element"/>
	<xsl:param name="location"/>

	<xsl:variable name="diff" select="$level - $depth"/>
	
	<xsl:variable name="totalList">
		<xsl:choose>
			<xsl:when test="$diff > 0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:value-of select="count(key('level_id', $level_id)//*[name()=$element and ./@location = $location])"/>+</xsl:for-each>
			</xsl:when>
			<xsl:when test="$diff=0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:value-of select="count(key('level_id', $level_id)/*[name()=$element and ./@location = $location])"/>+</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
				<xsl:choose>
					<xsl:when test="$diff = -1"><xsl:value-of select="count(key('level_id', $level_id)/../*[name()=$element and ./@location = $location])"/>+</xsl:when>
					<xsl:when test="$diff = -2"><xsl:value-of select="count(key('level_id', $level_id)/../../*[name()=$element and ./@location = $location])"/>+</xsl:when>
					<xsl:when test="$diff = -3"><xsl:value-of select="count(key('level_id', $level_id)/../../../*[name()=$element and ./@location = $location])"/>+</xsl:when>
					<xsl:when test="$diff = -3"><xsl:value-of select="count(key('level_id', $level_id)/../../../../*[name()=$element and ./@location = $location])"/>+</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:call-template name="getSum">
		<xsl:with-param name="list" select="$totalList"/>
	</xsl:call-template>
</xsl:template>

<!-- Count the number of different elements that should display in the document to generate
		Param:		level is the level in the tree zone, either prd (0), frm (1), str (2) or prs (3)
						element is the name of the element to display
 -->
<xsl:template name="countDifferentElement">
	<xsl:param name="level"/>
	<xsl:param name="element"/>

	<xsl:variable name="diff" select="$level - $depth"/>
	
	<xsl:variable name="list">	
		<xsl:choose>
			<xsl:when test="$diff > 0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:apply-templates select="key('level_id', $level_id)//*[name()=$element]/.." mode="list">
						<xsl:with-param name="element" select="$element"/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$diff=0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:apply-templates select="key('level_id', $level_id)/*[name()=$element]/.." mode="list">
						<xsl:with-param name="element" select="$element"/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
				<xsl:choose>
					<xsl:when test="$diff = -1">
						<xsl:apply-templates select="key('level_id', $level_id)/../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -2">
						<xsl:apply-templates select="key('level_id', $level_id)/../../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -3">
						<xsl:apply-templates select="key('level_id', $level_id)/../../../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -4">
						<xsl:apply-templates select="key('level_id', $level_id)/../../../../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:call-template name="getDiff">
		<xsl:with-param name="list" select="$list"/>
	</xsl:call-template>
</xsl:template>

<!-- Combine templates for proper display, with location
		Param: 	level is the level in the tree zone, either prd (0), frm (1), str (2) or prs (3)
						element is the name of the element to display
						mode can be either line (display as a separate line) or text (display text only)
						align define text horizontal alignment: left or center
						location is the location value for the additional section in leaflet
 -->
<xsl:template name="displayElementWithLocation">
	<xsl:param name="level"/>
	<xsl:param name="element"/>
	<xsl:param name="mode">line</xsl:param>
	<xsl:param name="align">left</xsl:param>
	<xsl:param name="location"/>
	
	<xsl:variable name="diff" select="$level - $depth"/>
	
	<xsl:variable name="list">	
		<xsl:choose>
			<xsl:when test="$diff > 0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:apply-templates select="key('level_id', $level_id)//*[name()=$element and ./@location = $location]/.." mode="list">
						<xsl:with-param name="element" select="$element"/>
						<xsl:with-param name="location" select="$location"/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$diff=0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:apply-templates select="key('level_id', $level_id)/*[name()=$element and ./@location = $location]/.." mode="list">
						<xsl:with-param name="element" select="$element"/>
						<xsl:with-param name="location" select="$location"/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
				<xsl:choose>
					<xsl:when test="$diff = -1">
						<xsl:apply-templates select="key('level_id', $level_id)/../*[name()=$element and ./@location = $location]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
							<xsl:with-param name="location" select="$location"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -2">
						<xsl:apply-templates select="key('level_id', $level_id)/../../*[name()=$element and ./@location = $location]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
							<xsl:with-param name="location" select="$location"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -3">
						<xsl:apply-templates select="key('level_id', $level_id)/../../../*[name()=$element and ./@location = $location]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
							<xsl:with-param name="location" select="$location"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -3">
						<xsl:apply-templates select="key('level_id', $level_id)/../../../../*[name()=$element and ./@location = $location]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
							<xsl:with-param name="location" select="$location"/>
						</xsl:apply-templates>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:variable name="combined-templates">
		<xsl:call-template name="combineTemplates">
			<xsl:with-param name="list" select="$list"/>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="$mode = 'count'">
			<xsl:call-template name="countItems">
				<xsl:with-param name="list" select="$combined-templates"/>
				<xsl:with-param name="sep">:</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$mode = 'list'"><xsl:value-of select="$combined-templates"/></xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="displayTemplates">
				<xsl:with-param name="list" select="$combined-templates"/>
				<xsl:with-param name="mode" select="$mode"/>
				<xsl:with-param name="align" select="$align"/>
				<xsl:with-param name="element" select="$element"/>
				<xsl:with-param name="context">no</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Combine templates for proper display
		Param: 	level is the level in the tree zone, either prd (0), frm (1), str (2) or prs (3)
						element is the name of the element to display
						mode can be either line (display as a separate line) or text (display text only)
						align define text horizontal alignment: left or center
 -->
<xsl:template name="displayElement">
	<xsl:param name="level"/>
	<xsl:param name="element"/>
	<xsl:param name="mode">line</xsl:param>
	<xsl:param name="align">left</xsl:param>
	
	<xsl:variable name="diff" select="$level - $depth"/>
	
	<xsl:variable name="list">	
		<xsl:choose>
			<xsl:when test="$diff > 0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:apply-templates select="key('level_id', $level_id)//*[name()=$element]/.." mode="list">
						<xsl:with-param name="element" select="$element"/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:when>
			<xsl:when test="$diff=0">
				<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
					<xsl:variable name="level_id" select="@ref-id"/>
					<xsl:apply-templates select="key('level_id', $level_id)/*[name()=$element]/.." mode="list">
						<xsl:with-param name="element" select="$element"/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
				<xsl:choose>
					<xsl:when test="$diff = -1">
						<xsl:apply-templates select="key('level_id', $level_id)/../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -2">
						<xsl:apply-templates select="key('level_id', $level_id)/../../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -3">
						<xsl:apply-templates select="key('level_id', $level_id)/../../../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
					<xsl:when test="$diff = -4">
						<xsl:apply-templates select="key('level_id', $level_id)/../../../../*[name()=$element]/.." mode="list">
							<xsl:with-param name="element" select="$element"/>
						</xsl:apply-templates>
					</xsl:when>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<xsl:variable name="combined-templates">;
		<xsl:call-template name="combineTemplates">
			<xsl:with-param name="list" select="$list"/>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="$mode = 'count'">
			<xsl:call-template name="countItems">
				<xsl:with-param name="list" select="$combined-templates"/>
				<xsl:with-param name="sep">:</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="$mode = 'list'"><xsl:value-of select="$combined-templates"/></xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="displayTemplates">
				<xsl:with-param name="list" select="$combined-templates"/>
				<xsl:with-param name="mode" select="$mode"/>
				<xsl:with-param name="align" select="$align"/>
				<xsl:with-param name="element" select="$element"/>
				<xsl:with-param name="context">no</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Retrieve all the matching elements and convert them into a ;- and /-separated list 
		Param:		element is the name of the element to retrieve
-->
<xsl:template match="*" mode="list">
	<xsl:param name="element"/>
	<xsl:param name="location"/>

	<xsl:choose>
		<xsl:when test="string-length($location) = 0"><xsl:for-each select="*[name() = $element]">
			<xsl:for-each select="pi-group/pi-leaf"><xsl:value-of select="@ref-id"/>;</xsl:for-each>
		</xsl:for-each>/</xsl:when>
		<xsl:otherwise><xsl:for-each select="*[name() = $element and ./@location = $location]">
			<xsl:for-each select="pi-group/pi-leaf"><xsl:value-of select="@ref-id"/>;</xsl:for-each>
		</xsl:for-each>/</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Count the number of occurrences of items in a list
		Param:		list is the string list of items
						occur contains as many X symbols as items found
						sep determines the separator between items
-->
<xsl:template name="countItems">
	<xsl:param name="list"/>
	<xsl:param name="occur"/>
	<xsl:param name="sep"/>
	
	<xsl:variable name="after-list" select="substring-after($list, $sep)"/>
	<xsl:variable name="new-occur">
		<xsl:value-of select="$occur"/>
		<xsl:if test="string-length($after-list) > 0">X</xsl:if>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="string-length($after-list) > 0">
			<xsl:call-template name="countItems">
				<xsl:with-param name="list" select="$after-list"/>
				<xsl:with-param name="occur" select="$new-occur"/>
				<xsl:with-param name="sep" select="$sep"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise><xsl:value-of select="$occur"/>X</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Combine lists of templates into a single one, taking into account the combined feature
		Param:		list is the list of template ids
-->
<xsl:template name="combineTemplates">
	<xsl:param name="list"/>
	
	<xsl:call-template name="compareLists">
		<xsl:with-param name="input" select="$list"/>
	</xsl:call-template>

</xsl:template>

<!-- Perform the comparison of ids of the list in order to provide the list of template ids to display
		Param:		input is the list of template ids to combine
						output is the list of combined template ids
-->
<xsl:template name="compareLists">
	<xsl:param name="input"/>
	<xsl:param name="output"/>
	
	<xsl:variable name="current" select="substring-before($input, '/')"/>
	<xsl:variable name="todo" select="substring-after($input, '/')"/>
	
	<xsl:variable name="update">
		<xsl:call-template name="compareElements">
			<xsl:with-param name="input" select="$current"/>
			<xsl:with-param name="ref" select="$output"/>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="string-length($todo) > 1">
			<xsl:call-template name="compareLists">
				<xsl:with-param name="input" select="$todo"/>
				<xsl:with-param name="ref" select="$update"/>
				<xsl:with-param name="output" select="$update"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise><xsl:value-of select="$update"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Compare elements: if already present, do not display; if not present, display
		Param:		input is the list of ids to compare
						ref is the reference to compare to
						output is the list of combined ids
-->
<xsl:template name="compareElements">
	<xsl:param name="input"/>
	<xsl:param name="ref"/>
	<xsl:param name="output"/>
	
	<xsl:variable name="current" select="substring-before($input, ';')"/>
	<xsl:variable name="todo" select="substring-after($input, ';')"/>
	
	<xsl:variable name="ref-a" select="substring-before($ref, ';')"/>
	<xsl:variable name="ref-b" select="substring-after($ref, ';')"/>
	
	<xsl:variable name="columned-current">:<xsl:value-of select="$current"/>:</xsl:variable>
	
	<xsl:variable name="update">
		<xsl:value-of select="$output"/>
		<xsl:value-of select="$ref-a"/>
		<xsl:if test="contains($ref-a, $columned-current) = false()">,:<xsl:value-of select="$current"/>:</xsl:if>;</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="string-length($todo) > 1">
			<xsl:call-template name="compareElements">
				<xsl:with-param name="input" select="$todo"/>
				<xsl:with-param name="ref" select="$ref-b"/>
				<xsl:with-param name="output" select="$update"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise><xsl:value-of select="$update"/></xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Display combined templates
		Param:		list is the list to display
						mode defines if template appeas in a line (line) or only as text (text)
						align defines the text horizontal alignment (left or center)
-->
<xsl:template name="displayTemplates">
	<xsl:param name="list"/>
	<xsl:param name="mode"/>
	<xsl:param name="align"/>
	<xsl:param name="element"/>
	<xsl:param name="context"/>
	
	<xsl:variable name="part-a" select="substring-before($list, ':')"/>
	<xsl:variable name="part-b" select="substring-after($list, ':')"/>
	<xsl:variable name="bef-sc" select="substring-before($list, ';')"/>
	
	<xsl:variable name="new-context">
		<xsl:choose>
			<xsl:when test="starts-with($part-a, ';')">no</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="$context = 'yes'">yes</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="contains($bef-sc, ',')">yes</xsl:when>
							<xsl:otherwise>no</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="/pim/documents/document[position() = $docpos]/@type != 'spc'">not-applicable</xsl:if>
		<xsl:if test="$depth > 1">not-applicable</xsl:if>
	</xsl:variable>
	
	<xsl:if test="string-length($part-a) > 0">
		<xsl:if test="not(contains($part-a, ',')) and not(contains($part-a, ';'))">
			<xsl:if test="$mode = 'line'">
				<xsl:call-template name="displayTemplateLine">
					<xsl:with-param name="id" select="$part-a"/>
					<xsl:with-param name="align" select="$align"/>
					<xsl:with-param name="element" select="$element"/>
					<xsl:with-param name="context" select="$new-context"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$mode = 'text'">
				<xsl:call-template name="displayTemplateText">
					<xsl:with-param name="id" select="$part-a"/>
					<xsl:with-param name="align" select="$align"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:if>
		<xsl:call-template name="displayTemplates">
			<xsl:with-param name="list" select="$part-b"/>
			<xsl:with-param name="mode" select="$mode"/>
			<xsl:with-param name="align" select="$align"/>
			<xsl:with-param name="element" select="$element"/>
			<xsl:with-param name="context" select="$new-context"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<!-- Return the proper name of the document type -->
<xsl:template name="getDocumentType">
	<xsl:choose>
		<xsl:when test="/pim/documents/document[position() = $docpos]/@type = 'spc'">S.P.C.</xsl:when>
		<xsl:when test="/pim/documents/document[position() = $docpos]/@type = 'annex2'">Annex II</xsl:when>
		<xsl:when test="/pim/documents/document[position() = $docpos]/@type = 'outer'">Outer Labelling</xsl:when>
		<xsl:when test="/pim/documents/document[position() = $docpos]/@type = 'blister'">Blister Labelling</xsl:when>
		<xsl:when test="/pim/documents/document[position() = $docpos]/@type = 'immed'">Immediate Labelling</xsl:when>
		<xsl:when test="/pim/documents/document[position() = $docpos]/@type = 'leaflet'">Package Leaflet</xsl:when>
	</xsl:choose>
</xsl:template>
	

</xsl:stylesheet>