<?xml version="1.0" encoding="utf-8"?>

<!-- 
	Version 2.6
	27 March 2006

	Author:
		Laurent Desqueper
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:ectd="http://www.ich.org/ectd" 
	xmlns:xlink="http://www.w3c.org/1999/xlink">

<!-- Replace a pattern in a text with the value provided 
		Param:		text is the text containing a pattern
						pattern is the text to replace
						value is the replacing text
-->
<xsl:template name="replace">
	<xsl:param name="text"/>
	<xsl:param name="pattern"/>
	<xsl:param name="value"/>
	<xsl:param name="pattern2"/>
	<xsl:param name="value2"/>
	
	<xsl:variable name="bothPatterns">
		<xsl:choose>
			<xsl:when test="string-length($pattern2) > 0"><xsl:value-of select="contains($text, $pattern) and contains($text, $pattern2)"/></xsl:when>
			<xsl:otherwise>false</xsl:otherwise>
		</xsl:choose>
	</xsl:variable> 
	
	<xsl:choose>
		<xsl:when test="$bothPatterns = 'true'">
			<xsl:choose>
				<xsl:when test="contains(substring-before($text, $pattern2), $pattern)">			<!-- text is like " xxxxx pattern yyyyyyy pattern2 zzzzz " -->
					
					<xsl:variable name="text_before" select="substring-before($text, $pattern)"/>
					<xsl:variable name="text_middle" select="substring-after(substring-before($text, $pattern2), $pattern)"/>
					<xsl:variable name="text_after" select="substring-after($text, $pattern2)"/>
					
					<xsl:value-of select="$text_before"/>
					<font color="blue"><xsl:value-of select="$value"/></font>
					<xsl:value-of select="$text_middle"/>
					<font color="blue"><xsl:value-of select="$value2"/></font>
					<xsl:value-of select="$text_after"/>
					
				</xsl:when>
				<xsl:otherwise>																										<!-- text is like " xxxxx pattern2 yyyyyyy pattern zzzzz " -->
					
					<xsl:variable name="text_before" select="substring-before($text, $pattern2)"/>
					<xsl:variable name="text_middle" select="substring-after(substring-before($text, $pattern), $pattern2)"/>
					<xsl:variable name="text_after" select="substring-after($text, $pattern)"/>
					
					<xsl:value-of select="$text_before"/>
					<font color="blue"><xsl:value-of select="$value2"/></font>
					<xsl:value-of select="$text_middle"/>
					<font color="blue"><xsl:value-of select="$value"/></font>
					<xsl:value-of select="$text_after"/>
					
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>										<!-- text is like " xxxxx pattern yyyyyyy " -->
			<xsl:variable name="text_before" select="substring-before($text, $pattern)"/>
			<xsl:variable name="text_after" select="substring-after($text, $pattern)"/>
			<xsl:choose>
				<xsl:when test="$text_before !='' or $text_after !=''">
					<xsl:value-of select="$text_before"/>
					<font color="blue"><xsl:value-of select="$value"/></font>
					<xsl:value-of select="$text_after"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$text"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>


<!-- Retrieve heading text in headings.xml as a node (i.e. with tag if any)
		Param: 	id is the identifier of the heading to find
		Other: 		lang is the global parameter of the document
 -->
<xsl:template name="getHeadingNode">
	<xsl:param name="id"/>
	<xsl:copy-of select="document('headings.xml')//multilang[@lang=$lang]/heading[@id=$id]/node()"/>
</xsl:template>

<!-- Retrieve heading text in headings.xml as a text (i.e. only text)
		Param: 	id is the identifier of the heading to find
						pattern is a text that needs to be replaced by data (e.g. product name)
						level is the numeric level of the data element that replaces the pattern
						element is the element name for replacement of the pattern
						pattern2 can be set to apply replacement of additional product
 -->
<xsl:template name="getHeadingText">
	<xsl:param name="id"/>
	<xsl:param name="pattern"/>
	<xsl:param name="level"/>
	<xsl:param name="element"/>
	<xsl:param name="pattern2"/>
	
	<xsl:variable name="productName"><xsl:call-template name="getProductName"/></xsl:variable>
	
	<xsl:choose>
		<xsl:when test="string-length($pattern) > 0">
			<xsl:variable name="value">
				<xsl:choose>
					<xsl:when test="string-length($element) > 0">
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level" select="$level"/>
							<xsl:with-param name="element" select="$element"/>
							<xsl:with-param name="mode">text</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$productName"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:call-template name="replace">
				<xsl:with-param name="text" select="document('headings.xml')//multilang[@lang=$lang]/heading[@id=$id]"/>
				<xsl:with-param name="pattern" select="$pattern"/>
				<xsl:with-param name="value" select="$value"/>
				<xsl:with-param name="pattern2" select="$pattern2"/>
				<xsl:with-param name="value2" select="$productName"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:value-of select="document('headings.xml')//multilang[@lang=$lang]/heading[@id=$id]"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Retrieve heading number in headings.xml as a text 
		Param:		id is the identifier of the heading to find
-->
<xsl:template name="getHeadingNumber">
	<xsl:param name="id"/>
	<xsl:value-of select="document('headings.xml')//multilang[@lang=$lang]/heading[@id=$id]/@nbr"/>
</xsl:template>

<!-- Display an empty line -->
<xsl:template name="displaySeparator">
	<xsl:if test="$section = ''">
		<tr class="separator">
			<td><xsl:text> </xsl:text></td>
		</tr>
	</xsl:if>
</xsl:template>

<!-- Insert a page break in the document -->
<xsl:template name="displayPageBreak">
	<tr class="page-break">
		<td><xsl:text> </xsl:text></td>
	</tr>
</xsl:template>

<!-- Display heading of level 1 
		Param:		id is the identifier of the heading to display
						secnr is the section number it corresponds to
						class is the css class to use for display
-->
<xsl:template name="displayHeading">
	<xsl:param name="id"/>
	<xsl:param name="secnr"/>
	<xsl:param name="class"/>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td align="center" valign="middle" width="50px">
				<img src="util/style/csection.gif">
					<xsl:attribute name="alt">§ <xsl:value-of select="$secnr"/></xsl:attribute>
				</img>
			</td>
		</xsl:if>
		<td width="100%">
			<xsl:if test="string-length($class) > 0">
				<xsl:attribute name="class"><xsl:value-of select="$class"/></xsl:attribute>
			</xsl:if>
			<table width="100%" cellpadding="0" cellspacing="0" style="color:black">
				<tr>
					<td width="30px">
						<h1>
							<xsl:call-template name="getHeadingNumber"><xsl:with-param name="id" select="$id"/></xsl:call-template>
						</h1>
					</td>
					<td>
						<xsl:choose>
							<xsl:when test="count(/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]) > 0">
								<xsl:variable name="comments">
									<xsl:apply-templates 
										select="/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]" mode="section"/>
								</xsl:variable>
								<h1>
									<a class="comment" title="Comments: {$comments}">
										<xsl:call-template name="getCustomHeading"><xsl:with-param name="id" select="$id"/></xsl:call-template>
									</a>
								</h1>
							</xsl:when>
							<xsl:otherwise>
								<h1>
									<xsl:call-template name="getCustomHeading"><xsl:with-param name="id" select="$id"/></xsl:call-template>
								</h1>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</table>
		</td>
	</tr>
	<xsl:if test="string-length($class) = 0">
		<xsl:call-template name="displaySeparator"/>
	</xsl:if>
</xsl:template>

<!-- Display heading of level 2 
		Param:		id is the identifier of the subheading to display
						secnr is the subsection number it corresponds to
-->
<xsl:template name="displaySubHeading">
	<xsl:param name="id"/>
	<xsl:param name="secnr"/>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td align="center" valign="middle" width="50px">
				<img src="util/style/csection.gif">
					<xsl:attribute name="alt">§ <xsl:value-of select="$secnr"/></xsl:attribute>
				</img>
			</td>
		</xsl:if>
		<xsl:variable name="number">
			<xsl:call-template name="getHeadingNumber"><xsl:with-param name="id" select="$id"/></xsl:call-template>
		</xsl:variable>
		<td width="100%">
			<table width="100%" cellpadding="0" cellspacing="0" style="color:black">
				<tr>
				<xsl:if test="string-length($number) > 0">
					<td width="30px">
						<h2><xsl:value-of select="$number"/></h2>
					</td>
				</xsl:if>
					<td>
						<xsl:choose>
							<xsl:when test="count(/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]) > 0">
								<xsl:variable name="comments">
									<xsl:apply-templates 
										select="/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]" mode="section"/>
								</xsl:variable>
								<h2>
									<a class="comment" title="Comments: {$comments}">
										<xsl:call-template name="getCustomHeading"><xsl:with-param name="id" select="$id"/></xsl:call-template>
									</a>
								</h2>
							</xsl:when>
							<xsl:otherwise>
								<h2>
									<xsl:call-template name="getCustomHeading"><xsl:with-param name="id" select="$id"/></xsl:call-template>
								</h2>
							</xsl:otherwise>
						</xsl:choose>
					</td>
				</tr>
			</table>
		</td>
	</tr>
	<xsl:if test="string-length($number) > 0">
		<xsl:call-template name="displaySeparator"/>
	</xsl:if>
</xsl:template>

<!-- Display heading of TOC
		Param:		id is the identifier of the subheading to display
-->
<xsl:template name="displayTocHeading">
	<xsl:param name="id"/>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td align="center" valign="middle" width="50px"><xsl:text> </xsl:text></td>
		</xsl:if>
		<td width="100%">
			<table width="100%" cellpadding="0" cellspacing="0" style="color:black">
				<tr>
					<td width="30px">
						<xsl:call-template name="getHeadingNumber"><xsl:with-param name="id" select="$id"/></xsl:call-template>
					</td>
					<td>
						<xsl:call-template name="getCustomHeading">
							<xsl:with-param name="id" select="$id"/>
						</xsl:call-template>
					</td>
				</tr>
			</table>
		</td>
	</tr>
</xsl:template>

<!-- Retrieve a custom heading, either from data or from headings; apply replacement if needed
		Param:		id is the name of the custom heading
-->
<xsl:template name="getCustomHeading">
	<xsl:param name="id"/>

	<xsl:variable name="ch">
		<xsl:choose>
			<xsl:when test="substring-before($id, '_take') != ''"><xsl:value-of select="substring-before($id, '_take')"/></xsl:when>
			<xsl:when test="substring-before($id, '_use') != ''"><xsl:value-of select="substring-before($id, '_use')"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="$id"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>

	<xsl:variable name="productName">
		<xsl:call-template name="getProductName"/>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="starts-with($id, 'head_pack') or $ch = 'pom_box_title' or $ch = 'otc_box_1'">
			<xsl:variable name="headPack">
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">1</xsl:with-param>
					<xsl:with-param name="element" select="$ch"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="text">
				<xsl:choose>
					<xsl:when test="string-length($headPack) > 0">
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element" select="$ch"/>
							<xsl:with-param name="mode">text</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$id"/></xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="string-length($headPack) > 0">
					<font color="blue">
						<xsl:call-template name="replace">
							<xsl:with-param name="text" select="$text"/>
							<xsl:with-param name="pattern">$des_product</xsl:with-param>
							<xsl:with-param name="value" select="$productName"/>
						</xsl:call-template>
					</font>
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name="replace">
						<xsl:with-param name="text" select="$text"/>
						<xsl:with-param name="pattern">$des_product</xsl:with-param>
						<xsl:with-param name="value" select="$productName"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$id"/></xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Display underlined heading 
		Param:		id is the identifier of the subheading to display
						secnr is the subsection number it corresponds to
-->
<xsl:template name="displayUnderlinedHeading">
	<xsl:param name="id"/>
	<xsl:param name="secnr"/>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td align="center" valign="middle" width="50px">
				<img src="util/style/csection.gif">
					<xsl:attribute name="alt">§ <xsl:value-of select="$secnr"/></xsl:attribute>
				</img>
			</td>
		</xsl:if>
		<td width="100%">
			<xsl:choose>
				<xsl:when test="count(/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]) > 0">
					<xsl:variable name="comments">
						<xsl:apply-templates 
							select="/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]" mode="section"/>
					</xsl:variable>
					<u>
						<a class="comment" title="Comments: {$comments}">
							<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$id"/></xsl:call-template>
						</a>
					</u>
				</xsl:when>
				<xsl:otherwise>
					<u>
						<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$id"/></xsl:call-template>
					</u>
				</xsl:otherwise>
			</xsl:choose>
		</td>
	</tr>
	<xsl:call-template name="displaySeparator"/>
</xsl:template>

<!-- Display bullet heading 
		Param:		id is the identifier of the subheading to display
						secnr is the subsection number it corresponds to
-->
<xsl:template name="displayBulletHeading">
	<xsl:param name="id"/>
	<xsl:param name="secnr"/>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td align="center" valign="middle" width="50px">
				<img src="util/style/csection.gif">
					<xsl:attribute name="alt">§ <xsl:value-of select="$secnr"/></xsl:attribute>
				</img>
			</td>
		</xsl:if>
		<td width="100%">
			<xsl:choose>
				<xsl:when test="count(/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]) > 0">
					<xsl:variable name="comments">
						<xsl:apply-templates 
							select="/pim/documents/document[position() = $docpos]/comment[@section = $secnr and @lang=$lang]" mode="section"/>
					</xsl:variable>
					<ul style="margin-left: 15px; margin-bottom: 0px">
						<li>
							<h2>
								<a class="comment" title="Comments: {$comments}">
									<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$id"/></xsl:call-template>
								</a>
							</h2>
						</li>
					</ul>
				</xsl:when>
				<xsl:otherwise>
					<ul style="margin-left: 15px; margin-bottom: 0px">
						<li>
							<h2>
								<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$id"/></xsl:call-template>
							</h2>
						</li>
					</ul>
				</xsl:otherwise>
			</xsl:choose>
		</td>
	</tr>
	<xsl:call-template name="displaySeparator"/>
</xsl:template>


<!-- Display simple text 
		Param:		id is the identifier of the text to display
-->
<xsl:template name="displayText">
	<xsl:param name="id"/>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td><xsl:text> </xsl:text></td>
		</xsl:if>
		<td width="100%">
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$id"/></xsl:call-template>
		</td>
	</tr>
</xsl:template>

<!-- Display simple node 
		Param:		id is the identifier of the node to display
-->
<xsl:template name="displayNode">
	<xsl:param name="id"/>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td><xsl:text> </xsl:text></td>
		</xsl:if>
		<td width="100%">
			<xsl:call-template name="getHeadingNode"><xsl:with-param name="id" select="$id"/></xsl:call-template>
		</td>
	</tr>
</xsl:template>

<!-- Display template as a separate line
		Param:		id is the identifier of the template to display
-->
<xsl:template name="displayTemplateLine">
	<xsl:param name="id"/>
	<xsl:param name="align">left</xsl:param>
	<xsl:param name="element"/>
	<xsl:param name="context">no</xsl:param>
	
	<xsl:if test="count(/pim/templates/neutral/template[@id=$id]) + count(/pim/templates/multilang[@lang=$lang]/template[@id=$id]) > 0">
		<tr>
			<xsl:if test="$caller = 'pimrs'">
				<td><xsl:text> </xsl:text></td>
			</xsl:if>
			<td width="100%" align="{$align}">
				<xsl:if test="$context = 'yes'">
					<xsl:attribute name="class">combined</xsl:attribute>
					<xsl:call-template name="displayContext">
						<xsl:with-param name="id" select="$id"/>
						<xsl:with-param name="element" select="$element"/>
					</xsl:call-template>
				</xsl:if>
				<xsl:apply-templates select="/pim/templates/neutral/template[@id=$id]"/>
				<xsl:apply-templates select="/pim/templates/multilang[@lang=$lang]/template[@id=$id]"/>
			</td>
		</tr>
	</xsl:if>
</xsl:template>

<!-- Display the context applicable to a template
		Param: 	id is the identifier of the template to display
-->
<xsl:template name="displayContext">
	<xsl:param name="id"/>
	<xsl:param name="element"/>

	<font size="-2">
		<ul style="margin-top:0mm; margin-bottom:0mm; margin-left:0mm">
			<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
				<xsl:for-each select="/pim/level_product//*[name() = $element]/pi-group/pi-leaf[@ref-id = $id]">
					<li><xsl:for-each select="ancestor-or-self::*">
						<xsl:value-of select="@name"/><xsl:text> </xsl:text>
					</xsl:for-each></li>
				</xsl:for-each>	
			</xsl:for-each>
		</ul>
	</font>
</xsl:template>

<!-- Display template as text only
		Param:		id is the identifier of the template to display
-->
<xsl:template name="displayTemplateText">
	<xsl:param name="id"/>
	
	<xsl:apply-templates select="/pim/templates/neutral/template[@id=$id]"/>
	<xsl:apply-templates select="/pim/templates/multilang[@lang=$lang]/template[@id=$id]"/>
</xsl:template>

<!-- Special case of the name of the medicinal product to display in the headings -->
<xsl:template name="getProductName">
	<xsl:variable name="nQualBeforeInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_before_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualAfterInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_after_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>

	<xsl:choose>
		<xsl:when test="contains($nQualBeforeInv, 'N') or contains($nQualAfterInv, 'N') ">
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">0</xsl:with-param>
				<xsl:with-param name="element">invented_name</xsl:with-param>
				<xsl:with-param name="mode">text</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">3</xsl:with-param>
				<xsl:with-param name="element">qual_before_inv</xsl:with-param>
				<xsl:with-param name="mode">text</xsl:with-param>
			</xsl:call-template>
			<xsl:text> </xsl:text>
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">0</xsl:with-param>
				<xsl:with-param name="element">invented_name</xsl:with-param>
				<xsl:with-param name="mode">text</xsl:with-param>
			</xsl:call-template>
			<xsl:text> </xsl:text>
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">3</xsl:with-param>
				<xsl:with-param name="element">qual_after_inv</xsl:with-param>
				<xsl:with-param name="mode">text</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>